// src/useLaze.ts
import { useReactiveRef } from "@lyonph/react-hooks";
import {
  useDebugValue,
  useEffect,
  useState
} from "react";
function useLaze() {
  const [visible, setVisible] = useState(false);
  const ref = useReactiveRef(() => null);
  const { current } = ref;
  useEffect(() => {
    setVisible(false);
    if (current) {
      const observer = new IntersectionObserver((entries) => {
        entries.forEach((entry) => {
          if (entry.target === current && entry.isIntersecting) {
            setVisible(true);
            observer.disconnect();
          }
        });
      });
      observer.observe(current);
      return () => {
        observer.unobserve(current);
        observer.disconnect();
      };
    }
    return void 0;
  }, [current]);
  const value = {
    ref,
    visible
  };
  useDebugValue(value);
  return value;
}
export {
  useLaze as default
};
//# sourceMappingURL=index.js.map
